Converts a file extension to a standardized language name used internally for detection pattern lookup.
See also
Other language-support:
get_comment_prefix(),
get_detection_patterns(),
get_supported_extensions(),
list_supported_languages()
Converts a file extension to a standardized language name used internally for detection pattern lookup.
Other language-support:
get_comment_prefix(),
get_detection_patterns(),
get_supported_extensions(),
list_supported_languages()