Generate node styling based on node types and theme
Source:R/put_diagram.R
generate_node_styling.RdGenerate node styling based on node types and theme
Usage
generate_node_styling(
workflow,
theme = "light",
show_workflow_boundaries = TRUE,
palette = NULL
)