Get Block Comment Syntax for File Extension
Source:R/language_registry.R
get_block_comment_syntax.RdReturns the block comment delimiters for languages that support them. Returns NULL for languages without block comment support.
R/language_registry.R
get_block_comment_syntax.RdReturns the block comment delimiters for languages that support them. Returns NULL for languages without block comment support.