Package load and attach hooks for putior. Sets up default options and initializes the logging namespace when the logger package is available.
Package load and attach hooks for putior. Sets up default options and initializes the logging namespace when the logger package is available.