Internal logging wrapper functions that provide structured logging throughout the putior package. Uses the logger package when available, silently degrades when logger is not installed.
Internal logging wrapper functions that provide structured logging throughout the putior package. Uses the logger package when available, silently degrades when logger is not installed.