Parses a comma-separated string of file names into a character vector, trimming whitespace from each entry.
See also
Other utilities:
get_diagram_themes(),
is_valid_put_annotation()
Parses a comma-separated string of file names into a character vector, trimming whitespace from each entry.
Other utilities:
get_diagram_themes(),
is_valid_put_annotation()