Returns a list of ellmer tool definitions for all putior functions that
can be exposed via MCP. This function is primarily used internally by
putior_mcp_server, but can also be used directly for
inspection or custom MCP server implementations.
Usage
putior_mcp_tools(include = NULL, exclude = c("run_sandbox"))Value
A list of ellmer tool definitions suitable for use with
mcptools::mcp_server().
See also
putior_mcp_server for starting the MCP server